# -*- coding: utf-8 -*-
"""
    pygments.styles.aimms
    ~~~~~~~~~~~~~~~~~~~~~

    Style inspired by AIMMS Text editor. Note this is not meant
    to be a complete style. It's merely meant to mimic AIMMS syntax highlighting.

    :copyright: Copyright 2006-2018 by the      S User Support team, see AUTHORS.
    :license:   T, see LICENSE for details.
"""

from pygments.style import Style
from pygments.token import Keyword, Name, Comment, String, Error, \
    Number, Operator, Whitespace


class AimmsLexerStyle(Style):
    """
    Style inspired by AIMMS syntax highlighter. Note this is not meant
    to be a complete style. It's merely meant to mimic AIMMS syntax highlighting.
    """

    default_style = ''

    styles = {
        Whitespace:            '#bbbbbb',
        Comment:               'italic #008000',
        String:                'italic #808080',
        Operator:              'bold #000000',
        Keyword:               '#0000ff',
		Keyword.Declaration:   'bold #000000',
        Keyword.Constant:      '',
		Name.Attribute:		   'bold #585858',
		Name.Builtin:		   '#a22a2a',
        Name.Function:         '#2c2cff',

        Name.Variable:         '#db7093',        
        Name.Parameter:        '#008b8b',
        Name.ElementParameter: '#008b8b',
        Name.DatabaseTable:    '#800080',

        Error:                 'bg:#e3d2d2 #a61717',
    }



# -*- coding: utf-8 -*-
from distutils.core import setup
import setuptools
import sys


_version = '2018.11.1'
_packages = ['style']

_short_description = "aimms-pygments-style is a colorful style for Pygments, especially adapted for AIMMS language"


_install_requires = [
    'pygments>=2'
]

setup(
    name='aimms-pygments-style',
    url='https://gitlab.com/ArthurdHerbemont/aimms-pygments-style',
    author='Arthur Herbemont',
    author_email='arthur.dherbemont@aimms.com',
    description=_short_description,
    version=_version,
    packages=_packages,
    install_requires=_install_requires,
    license='GPLv2',
    keywords='pygments syntax highlighting',
    entry_points={
        'pygments.styles': [
            'aimmslexer = style:AimmsLexerStyle',
        ]
    }
)
